#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name


journal_prompts_random = [
    'What are my 5 most important values? Is my life, mindset, and daily actions aligned with them?',
    'I am happy because ...',
    'How do I like to spend my day? What’s my favorite way of spending a day off?',
    'What is my perfect day? Do I live up to this vision?',
    'What are 5 things I like the most about myself? Why are these my strengths?',
    '5 things I like the least about myself? What can I do to work and grow through them, and unleash my full potential?',
    'What words have impacted my life and changed the way I think about something?',
    'What’s the one thing I couldn’t imagine my life without?',
    'What does unconditional love mean to me? Can I love myself and others unconditionally and what would that look like?',
    'How did I get where I am today? What shaped me? What made me me?',
    'What do I love about my life?',
    'Selfdescription in 10 words.',
    'What’s my biggest mistake? What did I learn from it?',
    'What gives me the most energy and inspiration?',
    '5 things that would make my life more fulfilled right now. How can I attract them into my life?',
    'What’s my deepest desire?',
    'What kind of an adult did I want to become as a child? Am I that person now?',
    'What’s my first memory?',
    'What’s something I will regret not doing?',
    'What kind of impression do I tend to leave on people? Is this the mark I want to leave?',
    'Imagine a world where I could do everything I like without being judged. Would anything change in my life?',
    'What scares me?',
    'In what situations do I undervalue myself?',
    "What's something I wish I had known 5/10/15 years ago? If I could give myself the advice I needed at that time, how would my life change? How can I apply this advice now?'",
    'When do I feel the happiest in my skin?',
    'If my body could talk, what would it say?',
    'What are my biggest regrets?',
    'What am I proud of the most?',
    'What is the best day in my life so far? Why?',
    'This week’s one worthy memory.',
    'What’s the most outrageous thing I’ve ever done? How did it make me feel?',
    'If I could travel back in time, what moment would I go back to experience again right away?',
    'If I could travel back in time, what’s the first thing I would change? Why is it so important? What can I do to let go of it?',
    'What’s the most recent change I’ve been through? How did I cope with it?',
    '1 thing I learned from today/this week/month/year ...',
    'What am I doing today that will benefit me tomorrow?',
    'Why am I grateful for the things I appreciate?',
    '1 positive word that can describe my day',
    'What is my intention for tomorrow?',
    'What or who made me the happiest today?',
    '3 people who have inspired me today…',
    '1 thing I can do to brighten someone else’s day…',
    'Today I found bliss in…',
    'How did I give and receive appreciation today?',
    'How did my positive affirmation impact me today?',
    'How will I embody one of my core values today?',
    'What am I going to do tomorrow to make it great?',
    'What 1 thing can I do today to take care of myself?',
    'What is a big win from today?',
    'Who is someone I want to wish well?',
    'What are the aspects of my life that I sometimes take for granted?',
    'Write a gratitude letter to someone who I haven’t thanked properly, but should have.',
    'List of 20 things that always make me smile and feel at peace.',
    'How am I feeling? Why do I feel that way? Who do I want to tell how I’m feeling?',
    'What worries me the most in life and why? How can I fix it?',
    'What do I need to feel safe? What makes me feel strong and in control of any situation?',
    'Is there something or someone I can’t forgive? Why? How does it impact my life? How can I let go of those feelings and emotions?',
    'How do I handle conflicts and disagreements? Is there room for improvement?',
    'How do I cope with uncertainty?',
    'How do I respond to a crisis? What can help me stay grounded and sane? What and who helps me overcome challenges?',
    'What do I need to be in balance?',
    'Do I get enough sleep? Do I usually wake up wellrested?',
    'When I am in a bad mood, what can I do to turn my day around?',
    'How do I express kindness, gratitude, love, and support? What is my love and support language? How can I share more joy?',
    'Am I judging and criticizing? How can I stop doing this?',
    '5 important life lessons from my parents/caretakers/close relatives/mentors/role models ...',
    'What do I value the most in a friend? Who is my closest friend? How have they changed me?',
    'What do I appreciate the most about my family/partner/teammate?',
    'What are the 3 things I look for in every relationship? What do I bring to every relationship?',
    'Who are the 5 people I spend most of my time with? How do they make me feel?',
    'Who fully understands me and knows me better than myself?',
    'Am I happy about my current romantic relationship? How can I deepen our bond?',
    'What are my weak sides as a partner/friend/sibling/colleague I should work on?',
    'Which relationships in my life could use some improvements? What went wrong and what can I do to fix it?',
    'How am I different from my parents? How did it impact my relationship with them? What parent do I want to be?',
    'Write a letter to someone I’ve lost. What do I have left to tell them?',
    'What did you work on today?',
    'What do you aim to accomplish today?',
    'What are your mustwins for today?',
    'What work did you accomplish today that you are most proud of?',
    'What are your priorities for today?',
    'What are the top three things you need to do today?',
    'What are your mustwins for the week?',
    'What is one way you could become a better teammate?',
    'What gave you energy today?',
    'What drained you today?',
    'What would you like to be working on next week? Next year? In five years?',
    'When was the last time you said, "thank you" to a coworker?',
    'When was the last time you asked for feedback on your work?',
    'What does success at work look like for you?',
    'In X years, what would you like to be doing for work?',
    'How can you make your life better today?',
    'What brings you energy?',
    'What drains you right now?',
    "In a couple of sentences, describe what's going on right now.",
    'How was your week?',
    'What are you most proud of right now?',
    'What would you like to improve about your life in the next 30 days?',
    'What does success look like to you?',
    'Who is the most important person in your life right now. Why?',
    'What is bringing you joy right now?',
    'What is making you sad right now?',
    'What are you thankful for right now?',
    'Who should you connect with right now? When was the last time you talked with them?',
    'How is social media impacting your life right now?',
    'What was the most surprising even you experienced this week?',
    'What do you want your legacy to be?',
    'When was the last time you exercised. Why?',
    'What places would you like to visit this year?',
    'What was the most exciting thing that happened this week?',
    'List the three people that give you energy',
    'What is one problem you encountered this week? How did you go about solving it?',
    'What is worrying you right now?',
    'What was the most disappointing thing you encountered recently. How did you overcome it?',
    'Rate how you are handling stress right now. Why?',
    'What is making you nervous right now?',
    'What is one good thing that happened to you today?',
    'What is your biggest overall accomplishment?',
    'What is the best thing that happened this week?',
    'What is something you had to overcome?',
    'What is something that makes you happy?',
    'What was your favorite part of your day?',
    'When you feel down, what makes you smile?',
    'What is a random act of kindness you’ve done or witnessed recently?',
    'What is your favorite hobby?',
    'What are three things you take for granted?',
    'What are you looking forward to today?',
    'What is something you wish to have done differently?',
    'What did you think about the most today?',
    'What are you looking forward to tomorrow?',
    'What’s the first thing that came up in your mind today?',
    'What is something you learned today?',
    'What hobby do you want to learn more about?',
    'What is your biggest roadblock to overcome today?',
    'Are there any distractions impacting your day?',
    'What was your favorite thing to do today?',
    'What are you grateful for today?',
    'What did you do today that made you feel good?',
    'What are your hopes and dreams for the future?',
    'What were some of the best moments of your life?',
    'What are some things you would like to change about yourself?',
    'What is your favorite thing about yourself?',
    'What is your favorite thing about your life?',
    'What is your favorite thing about the world?',
    'What are some things you would like to change about the world?',
    'How did you first get into music?',
    'What are some of your favorite bands/artists?',
    'What is your favorite song?',
    'What was the last concert you went to?',
    'Do you play any instruments? If so, what do you play?',
    'What are your thoughts on the current state of the music industry?',
    'What is your favorite musicrelated memory?',
    'Do you prefer live music or recorded music? Why?',
    'What role does music play in your life?'
]



# !/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Find a Random Question """


from random import sample

from baseblock import odds_of
from baseblock import BaseObject

from journal_prompts.dto import list_of_questions
from journal_prompts.dto import journal_prompts
from journal_prompts.dto import journal_prompts_random


class FindRandomQuestion(BaseObject):
    """ Find a Random Question """

    def __init__(self):
        """
        Created:
            14-Sept-2022
            craigtrim@gmail.com
        """
        BaseObject.__init__(self, __name__)

    def find(self) -> str:
        if odds_of(75):
            return sample(list_of_questions, 1)[0]

        if odds_of(75):
            return sample(journal_prompts, 1)[0]

        return sample(journal_prompts_random, 1)[0]
